--- 
--- !!! The default value of sched_name column is TestScheduler !!!
--- If you have existing data the scheduler name should correspond to your existing scheduler name
--- in Quartz configuration (quartz.scheduler.instanceName)
--- 

--
-- Drop all primary and foreign key constraints, so that we can define new ones
--
ALTER TABLE qrtz_simple_triggers DROP CONSTRAINT IF EXISTS pk_qrtz_simple_triggers;
ALTER TABLE qrtz_simple_triggers DROP CONSTRAINT IF EXISTS fk_qrtz_simple_triggers_qrtz_triggers;
ALTER TABLE qrtz_triggers DROP CONSTRAINT IF EXISTS fk_qrtz_triggers_qrtz_job_details;
ALTER TABLE qrtz_triggers DROP CONSTRAINT IF EXISTS pk_qrtz_triggers;
ALTER TABLE qrtz_cron_triggers DROP CONSTRAINT IF EXISTS pk_qrtz_cron_triggers;
ALTER TABLE qrtz_cron_triggers DROP CONSTRAINT IF EXISTS fk_qrtz_cron_triggers_qrtz_triggers;
ALTER TABLE qrtz_job_details DROP CONSTRAINT IF EXISTS pk_qrtz_job_details;
ALTER TABLE qrtz_fired_triggers DROP CONSTRAINT IF EXISTS pk_qrtz_fired_triggers;
ALTER TABLE qrtz_scheduler_state DROP CONSTRAINT IF EXISTS pk_qrtz_scheduler_state;
ALTER TABLE qrtz_calendars DROP CONSTRAINT IF EXISTS pk_qrtz_calendars;
ALTER TABLE qrtz_paused_trigger_grps DROP CONSTRAINT IF EXISTS pk_qrtz_paused_trigger_grps;
ALTER TABLE qrtz_locks DROP CONSTRAINT IF EXISTS pk_qrtz_locks;
ALTER TABLE qrtz_job_listeners DROP CONSTRAINT IF EXISTS fk_qrtz_job_listeners_qrtz_job_details;
ALTER TABLE qrtz_job_listeners DROP CONSTRAINT IF EXISTS pk_qrtz_job_listeners;
ALTER TABLE qrtz_trigger_listeners DROP CONSTRAINT IF EXISTS fk_qrtz_trigger_listeners_qrtz_triggers;
ALTER TABLE qrtz_trigger_listeners DROP CONSTRAINT IF EXISTS pk_qrtz_trigger_listeners;
COMMIT;

-- 
-- Drop tables that are no longer used
--
-- drop table qrtz_job_listeners; RM - dropping these causes DB corruption
-- drop table qrtz_trigger_listeners; RM - dropping these causes DB corruption
-- COMMIT;

--
-- Drop columns that are no longer used
--
ALTER TABLE qrtz_job_details DROP COLUMN is_volatile;
ALTER TABLE qrtz_triggers DROP COLUMN is_volatile;
ALTER TABLE qrtz_fired_triggers DROP COLUMN is_volatile;
COMMIT;

--
-- change some varchar(1)s to true bit/booleans
--
-- alter table QRTZ_FIRED_TRIGGERS alter column REQUESTS_RECOVERY boolean; RM - already boolean
-- alter table QRTZ_FIRED_TRIGGERS alter column IS_VOLATILE boolean; RM - we deleted this column above
-- alter table QRTZ_FIRED_TRIGGERS alter column IS_STATEFUL boolean; RM - already boolean & doesn't exist in 2.0
-- alter table QRTZ_JOB_DETAILS alter column REQUESTS_RECOVERY boolean; RM - already boolean
-- alter table QRTZ_JOB_DETAILS alter column IS_DURABLE boolean; RM - already boolean
-- COMMIT;

--
-- Add new columns that replace the 'is_stateful' column
--
ALTER TABLE qrtz_job_details ADD is_nonconcurrent BOOLEAN;
ALTER TABLE qrtz_job_details ADD is_update_data BOOLEAN;
COMMIT;
UPDATE qrtz_job_details SET is_nonconcurrent = is_stateful;
UPDATE qrtz_job_details SET is_update_data = is_stateful;
COMMIT;
ALTER TABLE qrtz_job_details DROP COLUMN is_stateful;
COMMIT;

ALTER TABLE qrtz_fired_triggers ADD is_nonconcurrent BOOLEAN;
COMMIT;
UPDATE qrtz_fired_triggers SET is_nonconcurrent = is_stateful;
COMMIT;
ALTER TABLE qrtz_fired_triggers DROP COLUMN is_stateful;
COMMIT;

--
-- Add new 'sched_time' column (schema ver 20 to 22 change)
--
ALTER TABLE qrtz_fired_triggers ADD sched_time BIGINT NOT NULL;
COMMIT;

--
-- Add new 'sched_name' column to all tables
--
ALTER TABLE qrtz_blob_triggers ADD sched_name VARCHAR(120) NOT NULL DEFAULT 'JobScheduler';
ALTER TABLE qrtz_calendars ADD sched_name VARCHAR(120) NOT NULL DEFAULT 'JobScheduler';
ALTER TABLE qrtz_cron_triggers ADD sched_name VARCHAR(120) NOT NULL DEFAULT 'JobScheduler';
ALTER TABLE qrtz_fired_triggers ADD sched_name VARCHAR(120) NOT NULL DEFAULT 'JobScheduler';
ALTER TABLE qrtz_job_details ADD sched_name VARCHAR(120) NOT NULL DEFAULT 'JobScheduler';
ALTER TABLE qrtz_locks ADD sched_name VARCHAR(120) NOT NULL DEFAULT 'JobScheduler';
ALTER TABLE qrtz_paused_trigger_grps ADD sched_name VARCHAR(120) NOT NULL DEFAULT 'JobScheduler';
ALTER TABLE qrtz_scheduler_state ADD sched_name VARCHAR(120) NOT NULL DEFAULT 'JobScheduler';
ALTER TABLE qrtz_simple_triggers ADD sched_name VARCHAR(120) NOT NULL DEFAULT 'JobScheduler';
ALTER TABLE qrtz_triggers ADD sched_name VARCHAR(120) NOT NULL DEFAULT 'JobScheduler';
COMMIT;

--
-- Add new simprop_triggers table
--
CREATE TABLE qrtz_simprop_triggers
(
    sched_name VARCHAR(120) NOT NULL,
    trigger_name VARCHAR(200) NOT NULL,
    trigger_group VARCHAR(200) NOT NULL,
    str_prop_1 VARCHAR(512) NULL,
    str_prop_2 VARCHAR(512) NULL,
    str_prop_3 VARCHAR(512) NULL,
    int_prop_1 INTEGER NULL,
    int_prop_2 INTEGER NULL,
    long_prop_1 BIGINT NULL,
    long_prop_2 BIGINT NULL,
    dec_prop_1 NUMERIC(13,4) NULL,
    dec_prop_2 NUMERIC(13,4) NULL,
    bool_prop_1 BOOLEAN NULL,
    bool_prop_2 BOOLEAN NULL
);
COMMIT;

--
-- Add all primary and foreign key constraints, based on new columns
--
ALTER TABLE qrtz_calendars ADD CONSTRAINT pk_qrtz_calendars PRIMARY KEY(sched_name,calendar_name);
ALTER TABLE qrtz_cron_triggers ADD CONSTRAINT pk_qrtz_cron_triggers PRIMARY KEY(sched_name,trigger_name,trigger_group);
ALTER TABLE qrtz_fired_triggers ADD CONSTRAINT pk_qrtz_fired_triggers PRIMARY KEY(sched_name,entry_id);
ALTER TABLE qrtz_paused_trigger_grps ADD CONSTRAINT pk_qrtz_paused_trigger_grps PRIMARY KEY(sched_name,trigger_group);
ALTER TABLE qrtz_scheduler_state ADD CONSTRAINT pk_qrtz_scheduler_state PRIMARY KEY(sched_name,instance_name);
ALTER TABLE qrtz_locks ADD CONSTRAINT pk_qrtz_locks PRIMARY KEY(sched_name,lock_name);
ALTER TABLE qrtz_job_details ADD CONSTRAINT pk_qrtz_job_details PRIMARY KEY(sched_name,job_name,job_group);
ALTER TABLE qrtz_simple_triggers ADD CONSTRAINT pk_qrtz_simple_triggers PRIMARY KEY(sched_name,trigger_name,trigger_group);
ALTER TABLE qrtz_simprop_triggers ADD CONSTRAINT pk_qrtz_simprop_triggers PRIMARY KEY(sched_name,trigger_name,trigger_group);
ALTER TABLE qrtz_triggers ADD CONSTRAINT pk_qrtz_triggers PRIMARY KEY(sched_name,trigger_name,trigger_group);
ALTER TABLE qrtz_cron_triggers ADD CONSTRAINT fk_qrtz_cron_triggers_qrtz_triggers FOREIGN KEY(sched_name,trigger_name,trigger_group)
    REFERENCES qrtz_triggers(sched_name,trigger_name,trigger_group) ON DELETE CASCADE;
ALTER TABLE qrtz_simple_triggers ADD CONSTRAINT fk_qrtz_simple_triggers_qrtz_triggers FOREIGN KEY(sched_name,trigger_name,trigger_group)
    REFERENCES qrtz_triggers(sched_name,trigger_name,trigger_group) ON DELETE CASCADE;
ALTER TABLE qrtz_simprop_triggers ADD CONSTRAINT fk_qrtz_simprop_triggers_qrtz_triggers FOREIGN KEY(sched_name,trigger_name,trigger_group)
    REFERENCES qrtz_triggers(sched_name,trigger_name,trigger_group) ON DELETE CASCADE;
ALTER TABLE qrtz_triggers ADD CONSTRAINT fk_qrtz_triggers_qrtz_job_details FOREIGN KEY(sched_name,job_name,job_group)
    REFERENCES qrtz_job_details (sched_name,job_name,job_group);
COMMIT;

--
-- Add new Green Hat properties table
--
CREATE TABLE greenhat_properties
(
    property_key VARCHAR(120) NULL,
    property_value VARCHAR(120) NULL
);
COMMIT;

INSERT INTO greenhat_properties VALUES('version', '2.2.x');
COMMIT;
